@@ -18,7 +18,7 @@ class BetwixtedButterfly(Source):
     ]
 
     def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
-        soup = self.soup(url)
+        soup = self.get_soup(url)
         metadata = []
 
         details_parent, synopsis_parent, *_ = soup.select('.elementor-text-editor')
@@ -56,7 +56,7 @@ class BetwixtedButterfly(Source):
         return novel, chapters, metadata
 
     def chapter(self, chapter: Chapter):
-        soup = self.soup(chapter.url)
+        soup = self.get_soup(chapter.url)
 
         elements = soup.select(".entry-inner section .elementor-element:not(.elementor-widget-button, "
                                ".elementor-column)")
