@@ -6,12 +6,13 @@ from ...models import Novel, Chapter, Metadata
 
 
 class Ktlchamber(Source):
+    name = 'KTL Chamber'
     base_urls = ('https://ktlchamber.wordpress.com',)
 
     chapter_regex = re.compile(r'Chapter[  ](\d+)\.[  ]?(.*)', flags=re.IGNORECASE)
 
     def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
-        soup = self.soup(url)
+        soup = self.get_soup(url)
 
         entry_content = soup.find('div', {'class': 'entry-content'})
 
@@ -62,7 +63,7 @@ class Ktlchamber(Source):
         return novel, chapters, []
 
     def chapter(self, chapter: Chapter):
-        soup = self.soup(chapter.url)
+        soup = self.get_soup(chapter.url)
 
         entry_content = soup.find('div', {'class': 'entry-content'})
         p_elements = entry_content.find_all('p')
