@@ -1,3 +1,4 @@
+import datetime
 from typing import Tuple, List
 
 from .source import Source
@@ -7,9 +8,10 @@ from ...models import Novel, Chapter, Metadata
 class RoyalRoad(Source):
     name = 'Royal Road'
     base_urls = ('https://www.royalroad.com',)
+    last_updated = datetime.date(2021, 8, 17)
 
     def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
-        soup = self.soup(url)
+        soup = self.get_soup(url)
 
         novel = Novel(
             title=soup.select_one('h1[property="name"]').text.strip(),
@@ -36,7 +38,7 @@ class RoyalRoad(Source):
         return novel, chapters, metadata
 
     def chapter(self, chapter: Chapter):
-        soup = self.soup(chapter.url)
+        soup = self.get_soup(chapter.url)
 
         contents = soup.select_one('.chapter-content')
         self.clean_contents(contents)
