@@ -1,3 +1,4 @@
+import datetime
 import json
 from typing import Tuple, List, Dict, Optional
 
@@ -15,6 +16,7 @@ chapter_info_url = ''
 class Webnovel(Source):
     name = 'Webnovel'
     base_urls = ('https://www.webnovel.com',)
+    last_updated = datetime.date(2021, 8, 25)
 
     csrf: str = None
 
@@ -27,7 +29,7 @@ class Webnovel(Source):
             self.csrf = self.session.cookies.get('_csrfToken')
 
     def novel(self, url: str) -> Tuple[Novel, List[Chapter], List[Metadata]]:
-        soup = self.soup(url)
+        soup = self.get_soup(url)
         novel_id = self.parse_novel_url(url)
         self.csrf = self.session.cookies.get('_csrfToken')
 
@@ -135,6 +137,7 @@ class Webnovel(Source):
         """
         :return: url of novel
         """
+        novel_url = novel_url.rstrip('/')
         try:
             return int(novel_url.split('/')[4])
         except ValueError:
@@ -145,7 +148,7 @@ class Webnovel(Source):
         """
         :return: novel_id, chapter_id
         """
-        pieces = chapter_url.split('/')
+        pieces = chapter_url.rstrip('/').split('/')
         try:
             return int(pieces[4]), int(pieces[5])
         except ValueError:
